MCPcopy Create free account
hub / github.com/ComputationalRobotics/XM-code / MarkColKernel

Function MarkColKernel

XM/include/Sparse/sparsesubmatrix.h:20–27  ·  view source on GitHub ↗

initialize kernal

Source from the content-addressed store, hash-verified

18
19// initialize kernal
20__global__ void MarkColKernel(int* row, int* col, size_s start, size_s end, size_l nnz, int* flag){
21 size_l i = blockIdx.x * blockDim.x + threadIdx.x;
22 if(i < nnz){
23 if(col[i] >= start && col[i] <= end){
24 flag[i] = 1;
25 }
26 }
27}
28
29// // take a submatrix of a sparse matrix CSR (only take rows)
30// __global__ void SubRowKernel(int* row, int* col, size_s start, size_s end, size_l nnz, int* flag){

Callers

nothing calls this directly

Calls

no outgoing calls

Tested by

no test coverage detected